%% This is file mdfont.def.
%%
%% Copyright 2003 Paul Pichaureau for the MathDesign Project
%% All rights reserved.
%%
%% This file is part of the mathdesign package v2.31
%% --------------------------------------------------
%%
%% This program is free software; you can redistribute it and/or
%% modify it under the terms of the GNU General Public License
%% as published by the Free Software Foundation; either version 2
%% of the License, or (at your option) any later version.

%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.

%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
%% Public LaTeX Project Public
%%
%% --------------------------------------------------
%%
%% These file defined common font families, which can used
%% with the main family.
%%
%% N.B.: These fonts must be correctly installed on your system.
%%

\ProvidesFile{mdfont.def}
[2013/08/29 v2.31 (Math Design Project)]

%% ----------------------------------------------------------------
%% Computer Modern Symbol
%% ----------------------------------------------------------------

  \def\MD@font@name{xmdcmsy}
  \DeclareFontFamily{OMS}{\MD@font@name}{\skewchar\font48 }
  \DeclareFontShape{OMS}{\MD@font@name}{m}{n}{%
    <5><6><7><8><9><10>sgen*[\cmsy@ratio]cmsy%
    <10.95><12><14.4><17.28><20.74><24.88> s*[\cmsy@ratio] cmsy10%
  }{}
  \DeclareFontShape{OMS}{\MD@font@name}{b}{n}{%
    <5><6><7><8><9>sgen*[\cmsy@ratio]cmbsy%
    <10><10.95><12><14.4><17.28><20.74><24.88> s*[\cmsy@ratio] cmbsy10%
  }{}
  \DeclareFontShape{OMS}{\MD@font@name}{mb}{n}{%
    <5><6><7><8><9>sgen*[\cmsy@ratio]cmbsy%
    <10><10.95><12><14.4><17.28><20.74><24.88> s*[\cmsy@ratio] cmbsy10%
  }{}


%% ----------------------------------------------------------------
%% AMS Euler Fraktur
%% ----------------------------------------------------------------

  \def\MD@font@name{xmdeuf}
  \DeclareFontFamily{U}{\MD@font@name}{}
  \DeclareFontShape{U}{\MD@font@name}{m}{n}{%
    <-6> s * [\euf@ratio]eufm5<6-8> s * [\euf@ratio]eufm7<8-> s * [\euf@ratio]eufm10
  }{}
  \DeclareFontShape{U}{\MD@font@name}{b}{n}{%
    <-6> s * [\euf@ratio]eufb5<6-8> s * [\euf@ratio]eufb7<8-> s * [\euf@ratio]eufb10
  }{}
  \DeclareFontShape{U}{\MD@font@name}{mb}{n}{%
    <-6> s * [\euf@ratio]eufb5<6-8> s * [\euf@ratio]eufb7<8-> s * [\euf@ratio]eufb10
  }{}


% -------------------------------------------------------------------
% GFS Bodoni (greek letters for math)
% -------------------------------------------------------------------

\def\MD@font@name{mdgrb}

\DeclareFontFamily{OML}{mdgrb}{\skewchar \font =127}

\DeclareFontShape{OML}{mdgrb}{m}{n}{
   <-> s * [\grb@ratio] mdgrbr7m
}{}

\DeclareFontShape{OML}{mdgrb}{m}{it}{
   <->  s * [\grb@ratio] mdgrbri7m
}{}

\DeclareFontShape{OML}{mdgrb}{b}{n}{
   <->  s * [\grb@ratio] mdgrbb7m
}{}

\DeclareFontShape{OML}{mdgrb}{b}{it}{
   <->  s * [\grb@ratio] mdgrbbi7m
}{}

\DeclareFontShape{OML}{mdgrb}{m}{sl}{<->ssub * mdgrb/m/it}{}
\DeclareFontShape{OML}{mdgrb}{bx}{n}{<->ssub * mdgrb/b/n}{}
\DeclareFontShape{OML}{mdgrb}{bx}{it}{<->ssub * mdgrb/b/it}{}
\DeclareFontShape{OML}{mdgrb}{bx}{sl}{<->ssub * mdgrb/b/sl}{}
\DeclareFontShape{OML}{mdgrb}{md}{n}{<->ssub * mdgrb/b/n}{}
\DeclareFontShape{OML}{mdgrb}{md}{it}{<->ssub * mdgrb/b/it}{}
\DeclareFontShape{OML}{mdgrb}{md}{sl}{<->ssub * mdgrb/b/sl}{}
\DeclareFontShape{OML}{mdgrb}{b}{sl}{<->ssub * mdgrb/b/it}{}

% -------------------------------------------------------------------
% GFS Didot (greek letters for math)
% -------------------------------------------------------------------

\def\MD@font@name{mdgrd}

\DeclareFontFamily{OML}{mdgrd}{\skewchar \font =127}

\DeclareFontShape{OML}{mdgrd}{m}{n}{
   <-> s * [\grd@ratio] mdgrdr7m
}{}

\DeclareFontShape{OML}{mdgrd}{m}{it}{
   <->  s * [\grd@ratio] mdgrdri7m
}{}

\DeclareFontShape{OML}{mdgrd}{b}{n}{
   <->  s * [\grd@ratio] mdgrdb7m
}{}

\DeclareFontShape{OML}{mdgrd}{b}{it}{
   <->  s * [\grd@ratio] mdgrdbi7m
}{}

\DeclareFontShape{OML}{mdgrd}{m}{sl}{<->ssub * mdgrd/m/it}{}
\DeclareFontShape{OML}{mdgrd}{bx}{n}{<->ssub * mdgrd/b/n}{}
\DeclareFontShape{OML}{mdgrd}{bx}{it}{<->ssub * mdgrd/b/it}{}
\DeclareFontShape{OML}{mdgrd}{bx}{sl}{<->ssub * mdgrd/b/sl}{}
\DeclareFontShape{OML}{mdgrd}{md}{n}{<->ssub * mdgrd/b/n}{}
\DeclareFontShape{OML}{mdgrd}{md}{it}{<->ssub * mdgrd/b/it}{}
\DeclareFontShape{OML}{mdgrd}{md}{sl}{<->ssub * mdgrd/b/sl}{}
\DeclareFontShape{OML}{mdgrd}{b}{sl}{<->ssub * mdgrd/b/it}{}

% -------------------------------------------------------------------
% Adobe Minion Pro (greek letters for math)
% -------------------------------------------------------------------

\def\MD@font@name{mdgrm}

\DeclareFontFamily{OML}{mdgrm}{\skewchar \font =127}

\DeclareFontShape{OML}{mdgrm}{m}{n}{
   <-> s * [\grm@ratio] mdgrmr7m
}{}

\DeclareFontShape{OML}{mdgrm}{m}{it}{
   <->  s * [\grm@ratio] mdgrmri7m
}{}

\DeclareFontShape{OML}{mdgrm}{b}{n}{
   <->  s * [\grm@ratio] mdgrmb7m
}{}

\DeclareFontShape{OML}{mdgrm}{b}{it}{
   <->  s * [\grm@ratio] mdgrmbi7m
}{}

\DeclareFontShape{OML}{mdgrm}{m}{sl}{<->ssub * mdgrm/m/it}{}
\DeclareFontShape{OML}{mdgrm}{bx}{n}{<->ssub * mdgrm/b/n}{}
\DeclareFontShape{OML}{mdgrm}{bx}{it}{<->ssub * mdgrm/b/it}{}
\DeclareFontShape{OML}{mdgrm}{bx}{sl}{<->ssub * mdgrm/b/sl}{}
\DeclareFontShape{OML}{mdgrm}{md}{n}{<->ssub * mdgrm/b/n}{}
\DeclareFontShape{OML}{mdgrm}{md}{it}{<->ssub * mdgrm/b/it}{}
\DeclareFontShape{OML}{mdgrm}{md}{sl}{<->ssub * mdgrm/b/sl}{}
\DeclareFontShape{OML}{mdgrm}{b}{sl}{<->ssub * mdgrm/b/it}{}


%%\endinput
%%
%% End of file `mdfont.def'.
