%% This is file mdfont.def.
%%
%% Copyright 2003 Paul Pichaureau for the MathDesign Project
%% All rights reserved.
%%
%% This file is part of the mathdesign package v2.31
%% --------------------------------------------------
%%
%% This program is free software; you can redistribute it and/or
%% modify it under the terms of the GNU General Public License
%% as published by the Free Software Foundation; either version 2
%% of the License, or (at your option) any later version.

%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.

%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
%% Public LaTeX Project Public
%%
%% --------------------------------------------------
%%
%% These file defined common font families, which can used
%% with the main family.
%%
%% N.B.: These fonts must be correctly installed on your system.
%%

\ProvidesFile{mdttfont.def}
[2013/08/29 v2.31 (Math Design Project)]

%% ----------------------------------------------------------------
%% Adobe Courier
%% ----------------------------------------------------------------

\def\MD@font@name{pcr}
\DeclareFontFamily{OT1}{\MD@font@name}{\hyphenchar \font\m@ne}
\DeclareFontShape{OT1}{\MD@font@name}{m}{n}{
  <-> s * [\pcr@ratio] pcrr7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{sc}{
  <-> s * [\pcr@ratio] pcrrc7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{sl}{
  <-> s * [\pcr@ratio] pcrro7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{n}{
  <-> s * [\pcr@ratio] pcrb7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{sc}{
  <-> s * [\pcr@ratio] pcrbc7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{sl}{
  <-> s * [\pcr@ratio] pcrbo7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{it}{<-> ssub * \MD@font@name/m/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{n}{<-> ssub * \MD@font@name/b/n}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{sc}{<-> ssub * \MD@font@name/b/sc}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{sl}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{it}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{it}{<-> ssub * \MD@font@name/b/it}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{ui}{<-> ssub * \MD@font@name/m/it}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{ui}{<-> ssub * \MD@font@name/b/it}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{ui}{<-> ssub * \MD@font@name/b/it}{}
%% ----------------------------------------------------------------

\DeclareFontFamily{T1}{\MD@font@name}{\hyphenchar \font\m@ne}
\DeclareFontShape{T1}{\MD@font@name}{m}{n}{
  <-> s * [\pcr@ratio] pcrr8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sc}{
  <-> s * [\pcr@ratio] pcrrc8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sl}{
  <-> s * [\pcr@ratio] pcrro8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{n}{
  <-> s * [\pcr@ratio] pcrb8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sc}{
  <-> s * [\pcr@ratio] pcrbc8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sl}{
  <-> s * [\pcr@ratio] pcrbo8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{it}{<-> ssub * \MD@font@name/m/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{n}{<-> ssub * \MD@font@name/b/n}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sc}{<-> ssub * \MD@font@name/b/sc}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sl}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{it}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{it}{<-> ssub * \MD@font@name/b/it}{}

%% ----------------------------------------------------------------
%% URW Courier
%% ----------------------------------------------------------------

\def\MD@font@name{ucr}

\DeclareFontFamily{OT1}{\MD@font@name}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{n}{
  <-> s * [\ucr@ratio] ucrr7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{sc}{
  <-> s * [\ucr@ratio] ucrrc7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{sl}{
  <-> s * [\ucr@ratio] ucrro7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{n}{
  <-> s * [\ucr@ratio] ucrb7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{sc}{
  <-> s * [\ucr@ratio] ucrbc7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{sl}{
  <-> s * [\ucr@ratio] ucrbo7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{it}{<-> ssub * \MD@font@name/m/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{n}{<-> ssub * \MD@font@name/b/n}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{sc}{<-> ssub * \MD@font@name/b/sc}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{sl}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{it}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{it}{<-> ssub * \MD@font@name/b/it}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{ui}{<-> ssub * \MD@font@name/m/it}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{ui}{<-> ssub * \MD@font@name/b/it}{}
%% ----------------------------------------------------------------
\DeclareFontFamily{T1}{\MD@font@name}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{n}{
  <-> s * [\ucr@ratio] ucrr8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sc}{
  <-> s * [\ucr@ratio] ucrrc8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sl}{
  <-> s * [\ucr@ratio] ucrro8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{n}{
  <-> s * [\ucr@ratio] ucrb8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sc}{
  <-> s * [\ucr@ratio] ucrbc8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sl}{
  <-> s * [\ucr@ratio] ucrbo8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{it}{<-> ssub * \MD@font@name/m/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{n}{<-> ssub * \MD@font@name/b/n}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sc}{<-> ssub * \MD@font@name/b/sc}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sl}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{it}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{it}{<-> ssub * \MD@font@name/b/it}{}

%% ----------------------------------------------------------------
%% Computer Modern Typewriter
%% ----------------------------------------------------------------
    \def\MD@font@name{cmtt}
    \DeclareFontFamily{OT1}{\MD@font@name}{\hyphenchar \font\m@ne}
    \DeclareFontShape{OT1}{\MD@font@name}{m}{n}
  {%
    <5><6><7><8> s * [\cmtt@ratio] cmtt8<9> s * [\cmtt@ratio] cmtt9%
    <10><10.95> s * [\cmtt@ratio] cmtt10%
    <12><14.4><17.28><20.74><24.88> s * [\cmtt@ratio] cmtt12%
  }{}
  \DeclareFontShape{OT1}{\MD@font@name}{m}{it}
   {%
   <5><6><7><8><9>%
   <10><10.95><12><14.4><17.28><20.74><24.88> s * [\cmtt@ratio]cmitt10%
   }{}
   \DeclareFontShape{OT1}{cmtt}{m}{sl}
   {%
     <5><6><7><8><9>%
     <10><10.95><12><14.4><17.28><20.74><24.88> s * [\cmtt@ratio]cmsltt10%
   }{}
   \DeclareFontShape{OT1}{cmtt}{m}{sc}
   {%
     <5><6><7><8><9>%
     <10><10.95><12><14.4><17.28><20.74><24.88> s * [\cmtt@ratio]cmtcsc10%
   }{}
   \DeclareFontShape{OT1}{\MD@font@name}{m}{ui}
   {<-> ssub*[\cmtt@ratio]cmtt/m/it}{}
   \DeclareFontShape{OT1}{\MD@font@name}{bx}{n}
   {<-> ssub*[\cmtt@ratio]cmtt/m/n}{}
   \DeclareFontShape{OT1}{\MD@font@name}{bx}{it}
   {<-> ssub*[\cmtt@ratio]cmtt/m/it}{}
   \DeclareFontShape{OT1}{\MD@font@name}{bx}{ui}
   {<-> ssub*[\cmtt@ratio]cmtt/m/it}{}
%% ----------------------------------------------------------------
   \DeclareFontFamily{T1}{\MD@font@name}{\hyphenchar \font\m@ne}
\DeclareFontShape{T1}{\MD@font@name}{m}{n}{<5><6><7><8> s * [\cmtt@ratio]ectt0800%
 <9><10><10.95><12><14.4><17.28><20.74><24.88><29.86>%
 <35.83>sgenb*[\cmtt@ratio]ectt}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sl}{<5><6><7><8> s * [\cmtt@ratio]ectt0800%
 <9><10><10.95><12><14.4><17.28><20.74><24.88><29.86>%
 <35.83>sgenb*[\cmtt@ratio]ectt}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{it}{<5><6><7><8> s * [\cmtt@ratio]ectt0800%
 <9><10><10.95><12><14.4><17.28><20.74><24.88><29.86>%
 <35.83>sgenb*[\cmtt@ratio]ectt}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sc}{<5><6><7><8> s * [\cmtt@ratio]ectt0800%
 <9><10><10.95><12><14.4><17.28><20.74><24.88><29.86>%
 <35.83>sgenb*[\cmtt@ratio]ectc}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{n}%
 {<-> ssub*[\cmtt@ratio]cmtt/m/n}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{it}%
 {<-> ssub*[\cmtt@ratio]cmtt/m/it}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{n}{<-> ssub * \MD@font@name/bx/n}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sc}{<-> ssub * \MD@font@name/bx/sc}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sl}{<-> ssub * \MD@font@name/bx/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{it}{<-> ssub * \MD@font@name/bx/it}{}

%% -------------------------------------------------------------------
%% Bera (aka Bistream Vera)
%% -------------------------------------------------------------------

 \def\MD@font@name{fvm}

\DeclareFontFamily{T1}{\MD@font@name}{\hyphenchar \font -1}

\DeclareFontShape{T1}{\MD@font@name}{m}{n}{
   <-> s * [\fvm@ratio] fvmr8t
}{}

\DeclareFontShape{T1}{\MD@font@name}{m}{sl}{
   <-> s * [\fvm@ratio] fvmro8t
}{}

\DeclareFontShape{T1}{\MD@font@name}{b}{n}{
   <-> s * [\fvm@ratio] fvmb8t
}{}

\DeclareFontShape{T1}{\MD@font@name}{b}{sl}{
   <-> s * [\fvm@ratio] fvmbo8t
}{}

\DeclareFontShape{T1}{\MD@font@name}{m}{it}{<->ssub * \MD@font@name/m/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{n}{<->ssub * \MD@font@name/b/n}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sl}{<->ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{it}{<->ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{it}{<->ssub * \MD@font@name/b/it}{}

%%
%% End of file `mdfont.def'.
