%% This is file mdfont.def.
%%
%% Copyright 2003 Paul Pichaureau for the MathDesign Project
%% All rights reserved.
%%
%% This file is part of the mathdesign package v2.31
%% --------------------------------------------------
%%
%% This program is free software; you can redistribute it and/or
%% modify it under the terms of the GNU General Public License
%% as published by the Free Software Foundation; either version 2
%% of the License, or (at your option) any later version.

%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.

%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
%% Public LaTeX Project Public
%%
%% --------------------------------------------------
%%
%% These file defined common font families, which can used
%% with the main family.
%%
%% N.B.: These fonts must be correctly installed on your system.
%%

\ProvidesFile{mdsffont.def}
[2013/08/29 v2.31 (Math Design Project)]

%% ----------------------------------------------------------------
%% Adobe Helvetica
%% ----------------------------------------------------------------

\def\MD@font@name{phv}

\DeclareFontFamily{OT1}{\MD@font@name}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{n}{
  <-> s*[\phv@ratio] phvr7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{sc}{
  <-> s*[\phv@ratio] phvrc7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{sl}{
  <-> s*[\phv@ratio] phvro7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{mc}{n}{
  <-> s*[\phv@ratio] phvr7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{mc}{sc}{
  <-> s*[\phv@ratio] phvrc7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{mc}{sl}{
  <-> s*[\phv@ratio] phvro7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{n}{
  <-> s*[\phv@ratio] phvb7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{sc}{
  <-> s*[\phv@ratio] phvbc7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{sl}{
  <-> s*[\phv@ratio] phvbo7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{bc}{n}{
  <-> s*[\phv@ratio] phvb7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{bc}{sc}{
  <-> s*[\phv@ratio] phvbc7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{bc}{sl}{
  <-> s*[\phv@ratio] phvbo7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{it}{<->ssub * \MD@font@name/m/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{mc}{it}{<->ssub * \MD@font@name/mc/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{n}{<->ssub * \MD@font@name/b/n}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{sc}{<->ssub * \MD@font@name/b/sc}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{sl}{<->ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{it}{<->ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{it}{<->ssub * \MD@font@name/b/it}{}
\DeclareFontShape{OT1}{\MD@font@name}{bc}{it}{<->ssub * \MD@font@name/bc/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{ui}{<->ssub * \MD@font@name/m/it}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{ui}{<->ssub * \MD@font@name/b/it}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{ui}{<->ssub * \MD@font@name/b/it}{}

\DeclareFontFamily{T1}{\MD@font@name}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{n}{
  <-> s*[\phv@ratio] phvr8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sc}{
  <-> s*[\phv@ratio] phvrc8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sl}{
  <-> s*[\phv@ratio] phvro8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{mc}{n}{
  <-> s*[\phv@ratio] phvr8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{mc}{sc}{
  <-> s*[\phv@ratio] phvrc8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{mc}{sl}{
  <-> s*[\phv@ratio] phvro8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{n}{
  <-> s*[\phv@ratio] phvb8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sc}{
  <-> s*[\phv@ratio] phvbc8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sl}{
  <-> s*[\phv@ratio] phvbo8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{bc}{n}{
  <-> s*[\phv@ratio] phvb8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{bc}{sc}{
  <-> s*[\phv@ratio] phvbc8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{bc}{sl}{
  <-> s*[\phv@ratio] phvbo8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{it}{<->ssub * \MD@font@name/m/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{mc}{it}{<->ssub * \MD@font@name/mc/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{n}{<->ssub * \MD@font@name/b/n}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sc}{<->ssub * \MD@font@name/b/sc}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sl}{<->ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{it}{<->ssub * \MD@font@name/b/it}{}
\DeclareFontShape{T1}{\MD@font@name}{mb}{n}{<->ssub * \MD@font@name/b/n}{}
\DeclareFontShape{T1}{\MD@font@name}{mb}{sc}{<->ssub * \MD@font@name/b/sc}{}
\DeclareFontShape{T1}{\MD@font@name}{mb}{sl}{<->ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{mb}{it}{<->ssub * \MD@font@name/b/it}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{it}{<->ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bc}{it}{<->ssub * \MD@font@name/bc/sl}{}

%% ----------------------------------------------------------------
%% URW Gothic
%% ----------------------------------------------------------------

\def\MD@font@name{uag}

\DeclareFontFamily{OT1}{\MD@font@name}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{n}{
 <-> s*[\uag@ratio] uagr7t
 <-> s*[\uag@ratio] uagk7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{sc}{
 <-> s*[\uag@ratio] uagrc7t
 <-> s*[\uag@ratio] uagkc7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{sl}{
 <-> s*[\uag@ratio] uagro7t
 <-> s*[\uag@ratio] uagko7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{it}{
 <-> s*[\uag@ratio] uagri7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{n}{
 <-> s*[\uag@ratio] uagb7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{sc}{
 <-> s*[\uag@ratio] uagbc7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{sl}{
 <-> s*[\uag@ratio] uagbo7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{it}{
 <-> s*[\uag@ratio] uagbi7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{db}{n}{
 <-> s*[\uag@ratio] uagd7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{db}{sc}{
 <-> s*[\uag@ratio] uagdc7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{db}{sl}{
 <-> s*[\uag@ratio] uagdo7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{n}{<-> ssub * \MD@font@name/b/n}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{sc}{<-> ssub * \MD@font@name/b/sc}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{sl}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{it}{<-> ssub * \MD@font@name/b/it}{}
\DeclareFontShape{OT1}{\MD@font@name}{db}{it}{<-> ssub * \MD@font@name/db/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{ui}{<-> ssub * \MD@font@name/m/it}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{ui}{<-> ssub * \MD@font@name/b/it}{}
%% ----------------------------------------------------------------
\DeclareFontFamily{T1}{\MD@font@name}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{n}{
 % <-> s*[\uag@ratio] uagr8t
 <-> s*[\uag@ratio] uagk8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sc}{
 <-> s*[\uag@ratio] uagrc8t
 <-> s*[\uag@ratio] uagkc8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sl}{
 <-> s*[\uag@ratio] uagro8t
 <-> s*[\uag@ratio] uagko8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{it}{
 <-> s*[\uag@ratio] uagri8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{n}{
 <-> s*[\uag@ratio] uagb8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sc}{
 <-> s*[\uag@ratio] uagbc8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sl}{
 <-> s*[\uag@ratio] uagbo8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{it}{
 <-> s*[\uag@ratio] uagbi8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{db}{n}{
 <-> s*[\uag@ratio] uagd8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{db}{sc}{
 <-> s*[\uag@ratio] uagdc8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{db}{sl}{
 <-> s*[\uag@ratio] uagdo8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{n}{<-> ssub * \MD@font@name/b/n}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sc}{<-> ssub * \MD@font@name/b/sc}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sl}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{it}{<-> ssub * \MD@font@name/b/it}{}
\DeclareFontShape{T1}{\MD@font@name}{mb}{n}{<-> ssub * \MD@font@name/b/n}{}
\DeclareFontShape{T1}{\MD@font@name}{mb}{sc}{<-> ssub * \MD@font@name/b/sc}{}
\DeclareFontShape{T1}{\MD@font@name}{mb}{sl}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{mb}{it}{<-> ssub * \MD@font@name/b/it}{}
\DeclareFontShape{T1}{\MD@font@name}{db}{it}{<-> ssub * \MD@font@name/db/sl}{}

%% ----------------------------------------------------------------
%% URW Helvetica
%% ----------------------------------------------------------------

\def\MD@font@name{uhv}

\DeclareFontFamily{OT1}{\MD@font@name}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{n}{
 <-> s*[\uhv@ratio] uhvr7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{sc}{
 <-> s*[\uhv@ratio] uhvrc7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{sl}{
 <-> s*[\uhv@ratio] uhvro7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{it}{
 <-> s*[\uhv@ratio] uhvri7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{mc}{n}{
 <-> s*[\uhv@ratio] uhvr7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{mc}{sc}{
 <-> s*[\uhv@ratio] uhvrc7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{mc}{sl}{
 <-> s*[\uhv@ratio] uhvro7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{mc}{it}{
 <-> s*[\uhv@ratio] uhvri7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{n}{
 <-> s*[\uhv@ratio] uhvb7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{sc}{
 <-> s*[\uhv@ratio] uhvbc7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{sl}{
 <-> s*[\uhv@ratio] uhvbo7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{it}{
 <-> s*[\uhv@ratio] uhvbi7t
}{}
\DeclareFontShape{OT1}{\MD@font@name}{bc}{n}{
 <-> s*[\uhv@ratio] uhvb7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{bc}{sc}{
 <-> s*[\uhv@ratio] uhvbc7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{bc}{sl}{
 <-> s*[\uhv@ratio] uhvbo7tn
}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{n}{<-> ssub * \MD@font@name/b/n}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{sc}{<-> ssub * \MD@font@name/b/sc}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{sl}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{it}{<-> ssub * \MD@font@name/b/it}{}
\DeclareFontShape{OT1}{\MD@font@name}{bc}{it}{<-> ssub * \MD@font@name/bc/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{ui}{<-> ssub * \MD@font@name/m/it}{}
\DeclareFontShape{OT1}{\MD@font@name}{b}{ui}{<-> ssub * \MD@font@name/b/it}{}
%% ----------------------------------------------------------------
\DeclareFontFamily{T1}{\MD@font@name}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{n}{
 <-> s*[\uhv@ratio] uhvr8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sc}{
 <-> s*[\uhv@ratio] uhvrc8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sl}{
 <-> s*[\uhv@ratio] uhvro8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{it}{
 <-> s*[\uhv@ratio] uhvri8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{mc}{n}{
 <-> s*[\uhv@ratio] uhvr8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{mc}{sc}{
 <-> s*[\uhv@ratio] uhvrc8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{mc}{sl}{
 <-> s*[\uhv@ratio] uhvro8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{mc}{it}{
 <-> s*[\uhv@ratio] uhvri8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{n}{
 <-> s*[\uhv@ratio] uhvb8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sc}{
 <-> s*[\uhv@ratio] uhvbc8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sl}{
 <-> s*[\uhv@ratio] uhvbo8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{it}{
 <-> s*[\uhv@ratio] uhvbi8t
}{}
\DeclareFontShape{T1}{\MD@font@name}{bc}{n}{
 <-> s*[\uhv@ratio] uhvb8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{bc}{sc}{
 <-> s*[\uhv@ratio] uhvbc8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{bc}{sl}{
 <-> s*[\uhv@ratio] uhvbo8tn
}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{n}{<-> ssub * \MD@font@name/b/n}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sc}{<-> ssub * \MD@font@name/b/sc}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sl}{<-> ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{it}{<-> ssub * \MD@font@name/b/it}{}
\DeclareFontShape{T1}{\MD@font@name}{bc}{it}{<-> ssub * \MD@font@name/bc/sl}{}

%% ----------------------------------------------------------------
%% Computer Modern Sans
%% ----------------------------------------------------------------
\def\MD@font@name{cmss}

 \DeclareFontFamily{OT1}{\MD@font@name}{\hyphenchar\font45 }
 \DeclareFontShape{OT1}{\MD@font@name}{m}{n}
  {%
  <5><6><7><8> s*[\cmss@ratio] cmss8%
  <9> s*[\cmss@ratio] cmss9%
  <10><10.95> s*[\cmss@ratio] cmss10%
  <12><14.4> s*[\cmss@ratio] cmss12%
  <17.28><20.74><24.88> s*[\cmss@ratio] cmss17%
  }{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{it}
  {<-> ssub*[\cmss@ratio] cmss/m/sl}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{sl}
 {%
  <5><6><7><8> s*[\cmss@ratio] cmssi8<9> s*[\cmss@ratio] cmssi9%
  <10><10.95> s*[\cmss@ratio] cmssi10%
  <12><14.4> s*[\cmss@ratio] cmssi12%
  <17.28><20.74><24.88> s*[\cmss@ratio] cmssi17%
  }{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{sc}
  {<-> ssub*[\cmss@ratio] cmr/m/sc}{}
\DeclareFontShape{OT1}{\MD@font@name}{m}{ui}
  {<-> ssub*[\cmss@ratio] cmr/m/ui}{}
\DeclareFontShape{OT1}{\MD@font@name}{sbc}{n}
  {%
  <5><6><7><8><9> s*[\cmss@ratio] cmssdc10%
  <10><10.95><12><14.4><17.28><20.74><24.88> s*[\cmss@ratio] cmssdc10%
  }{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{n}
  {%
  <5><6><7><8><9> s*[\cmss@ratio] cmssbx10%
  <10><10.95><12><14.4><17.28><20.74><24.88> s*[\cmss@ratio] cmssbx10%
  }{}
\DeclareFontShape{OT1}{\MD@font@name}{bx}{ui}
  {<-> ssub*[\cmss@ratio] cmr/bx/ui}{}
%% ----------------------------------------------------------------
\DeclareFontFamily{T1}{\MD@font@name}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{n}{<5><6><7><8><9><10><10.95><12><14.4>%
 <17.28><20.74><24.88><29.86><35.83>sgenb*[\cmss@ratio] ecss}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sl}{<5><6><7><8><9><10><10.95><12><14.4>%
 <17.28><20.74><24.88><29.86><35.83>sgenb*[\cmss@ratio] ecsi}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{it}{<5><6><7><8><9><10><10.95><12><14.4>%
 <17.28><20.74><24.88><29.86><35.83>sgenb*[\cmss@ratio] ecsi}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{n}{<5><6><7><8><9><10><10.95><12><14.4>%
 <17.28><20.74><24.88><29.86><35.83>sgenb*[\cmss@ratio] ecsx}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{it}{<5><6><7><8><9><10><10.95><12><14.4>%
 <17.28><20.74><24.88><29.86><35.83>sgenb*[\cmss@ratio] ecso}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sl}{<5><6><7><8><9><10><10.95><12><14.4>%
 <17.28><20.74><24.88><29.86><35.83>sgenb*[\cmss@ratio] ecso}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sc}%
  {<-> ssub*[\cmss@ratio] cmr/m/sc}{}
\DeclareFontShape{T1}{\MD@font@name}{sbc}{n}{%
  <5><6><7><8><9><10><10.95><12><14.4><17.28>%
  <20.74><24.88> s*[\cmss@ratio] ecssdc10
  }{}
\DeclareFontShape{T1}{\MD@font@name}{b}{n}{<-> ssub * \MD@font@name/bx/n}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sc}{<-> ssub * \MD@font@name/bx/sc}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sl}{<-> ssub * \MD@font@name/bx/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{it}{<-> ssub * \MD@font@name/bx/it}{}

%% -------------------------------------------------------------------
%% Bera (aka Bistream Vera)
%% -------------------------------------------------------------------

 \def\MD@font@name{fve}

\DeclareFontFamily{T1}{\MD@font@name}{}

\DeclareFontShape{T1}{\MD@font@name}{m}{n}{
  <-> s*[\fve@ratio] fver8t
}{}

\DeclareFontShape{T1}{\MD@font@name}{m}{sl}{
  <-> s*[\fve@ratio] fvero8t
}{}

\DeclareFontShape{T1}{\MD@font@name}{b}{n}{
  <-> s*[\fve@ratio] fveb8t
}{}

\DeclareFontShape{T1}{\MD@font@name}{b}{sl}{
  <-> s*[\fve@ratio] fvebo8t
}{}

\DeclareFontShape{T1}{\MD@font@name}{m}{it}{<->ssub * \MD@font@name/m/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{n}{<->ssub * \MD@font@name/b/n}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sl}{<->ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{it}{<->ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{it}{<->ssub * \MD@font@name/b/it}{}

%% -------------------------------------------------------------------

 \def\MD@font@name{fvs}

\DeclareFontFamily{T1}{\MD@font@name}{}

\DeclareFontShape{T1}{\MD@font@name}{b}{n}{
  <-> s*[\fvs@ratio] fvsb8t
}{}

\DeclareFontShape{T1}{\MD@font@name}{b}{it}{
  <-> s*[\fvs@ratio] fvsbo8t
}{}

\DeclareFontShape{T1}{\MD@font@name}{m}{n}{
  <-> s*[\fvs@ratio] fvsr8t
}{}

\DeclareFontShape{T1}{\MD@font@name}{m}{it}{
  <-> s*[\fvs@ratio] fvsro8t
}{}

\DeclareFontShape{T1}{\MD@font@name}{bx}{n}{<->ssub * \MD@font@name/b/n}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{it}{<->ssub * \MD@font@name/b/it}{}
\DeclareFontShape{T1}{\MD@font@name}{b}{sl}{<->ssub * \MD@font@name/b/it}{}
\DeclareFontShape{T1}{\MD@font@name}{bx}{sl}{<->ssub * \MD@font@name/b/sl}{}
\DeclareFontShape{T1}{\MD@font@name}{m}{sl}{<->ssub * \MD@font@name/m/it}{}

%%\endinput
%%
%% End of file `mdfont.def'.
